# Example:
#   rooms can be locked (note: not best way to do this!)
#   rooms can contain items
#   player can examine/take/drop items
#   player can view inventory

from adventurelib import *

Room.items = Bag()
Room.locked = False

dark_room = Room("""
You are in a dark room.
There is a door to the north.
""")
doormat = Item("an old doormat", "doormat")
key = Item("a rusty key", "key")
dark_room.items.add(doormat)
doormat.contains = key

big_room = Room("""
You are in a big room.
You win the game.
""")
key.unlocks = big_room
dark_room.north = big_room
big_room.locked = True

current_room = dark_room
inventory = Bag()

@when("north", direction="north")
@when("south", direction="south")
@when("east", direction="east")
@when("west", direction="west")
def go(direction):
    global current_room
    room = current_room.exit(direction)
    if room:
        if room.locked:
            say("The door is locked")
        else:
            current_room = room
            say(f"You go {direction}")
            look()
    else:
        say(f"No exit {direction}")


@when('take ITEM')
def take(item):
    obj = current_room.items.take(item)
    if obj:
        say(f"You pick up {obj}")
        inventory.add(obj)
    else:
        say(f"There is no {item} here.")


@when('drop ITEM')
def drop(item):
    obj = inventory.take(item)
    if obj:
        say(f"You drop {obj}")
        current_room.items.add(obj)
    else:
        say(f"You do not have {item}")


@when('look')
def look():
    say(current_room)
    if current_room.items:
        for i in current_room.items:
            say(f"{i} is here.")


@when('inventory')
def show_inventory():
    say('You have:')
    for thing in inventory:
        say(thing)

@when('use ITEM')
def use(item):
    obj = inventory.find(item)
    if obj:
        if obj.unlocks:
            say(f"You unlock the door.")
            obj.unlocks.locked = False
            inventory.take(item)
        else:
            say(f"I don't know how to use {item}")
    else:
        say(f"You are not holding {item}")

@when("examine ITEM")
def examine(item):
    obj = current_room.items.find(item)
    if obj:
        say(f"You examine {item}.")
        if obj.contains:
            say(f"A {obj.contains} is under {item}")
            current_room.items.add(obj.contains)
            current_room.items.take(item)


look()
start()
